@@ -171,7 +171,7 @@
 /* ODBC support */
 /* #undef ODBC_FOUND */
 /* Do we have libdbi ? */
-/* #undef LIBDBI_FOUND */
+#define LIBDBI_FOUND
 #ifndef HAVE_POSTGRESQL_LIBPQ_FE_H
 #define HAVE_POSTGRESQL_LIBPQ_FE_H
 #endif
